#
# spec file for package ibus
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor %nil

%define with_gtk4 0
%define with_wayland 1
%define with_emoji 1

%if "%{flavor}" == "gtk4"
%define with_gtk4 1
%define nsuffix _%{flavor}
%endif

%if ! %{defined _distconfdir}
%define _distconfdir %{_sysconfdir}
%else
%define use_usretc 1
%endif

%define _name   ibus
Name:           %{_name}%{?nsuffix}
Version:        1.5.31
Release:        2.1
Summary:        The "Intelligent Input Bus" input method
License:        LGPL-2.1-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/ibus/
Source:         https://github.com/ibus/ibus/releases/download/%{version}/%{_name}-%{version}.tar.gz
Source2:        README.SUSE
Source3:        xim.ibus.suse.template
Source4:        xim.d-ibus-121
Source7:        macros.ibus
Source10:       ibus-autostart
Source11:       ibus-autostart.desktop
Source12:       20-defaults-openSUSE.conf
Source99:       baselibs.conf
# PATFH-FIX-OPENSUSE ibus-xim-fix-re-focus-after-lock.patch bnc#874869 tiwai@suse.de
# Fix lost XIM input after screenlock
Patch4:         ibus-xim-fix-re-focus-after-lock.patch
# PATCH-FIX-UPSTREAM ftake@geeko.jp
# Select an IM engine instead of xkb engine at the first login
Patch8:         im-engines-precede-xkb.patch
# PATCH-FIX-OPENSUSE ibus-fix-Signal-does-not-exist.patch hillwood@opensuse.org
# panel.vala: The name `Signal' does not exist in the context of `Posix' in Leap 15.1 and below
Patch9:         ibus-fix-Signal-does-not-exist.patch
# PATCH-FIX-SLE hide-setup-menu.patch bnc#899259  qzhao@suse.com
# ibus-setup should not launch from main menu.
Patch10:        hide-setup-menu.patch
# PATCH-FIX-SLE setup-switch-im.patch bnc#899259  qzhao@suse.com
# switch to ibus when ibus not running.
Patch11:        setup-switch-im.patch
# PATCH-FIX-SLE ibus-disable-engines-preload-in-GNOME.patch bnc#1036729 qzhao@suse.com
# Disable ibus engines preload in GNOME for These works are handled by gnome-shell.
Patch12:        ibus-disable-engines-preload-in-GNOME.patch
# PATCH-FIX-UPSTREAM ibus-socket-name-compatibility.patch bsc#1171442, gh#ibus/ibus#2195 qkzhu@suse
# Compatibility workaround for ibus-use-wayland-display-for-socket-name.patch
# Qt5 does not be update to the new version and patch for ibus on Leap 15,
# it still needs this patch on leap 15. (boo#1187202)
Patch15:        ibus-socket-name-compatibility.patch
# PATCH-FIX-UPSTREAM ibus-ui-gtk3-restart-via-systemd.patch
# Allow ibus-ui-gtk3 to restart ibus-daemon when it is launched by systemd
Patch16:        ibus-ui-gtk3-restart-via-systemd.patch
# PATCH-FIX-UPSTREAM ibus-gcc15.patch
Patch17:        ibus-gcc15-1.patch
# PATCH-FIX-UPSTREAM ibus-gcc15-2.patch
Patch18:        ibus-gcc15-2.patch
BuildRequires:  pkgconfig(dbusmenu-glib-0.4)
BuildRequires:  pkgconfig(dbusmenu-gtk3-0.4)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(systemd)
%if ! 0%{?with_gtk4}
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  gobject-introspection-devel >= 0.9.6
BuildRequires:  gtk-doc >= 1.9
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-dbus-python-devel
BuildRequires:  python3-gobject-devel
BuildRequires:  unicode-ucd
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(dconf) >= 0.7.5
BuildRequires:  pkgconfig(glib-2.0) >= 2.34.0
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libnotify) >= 0.7
BuildRequires:  pkgconfig(python3)
# copy_deep method is supported since 0.31.1
BuildRequires:  vala >= 0.31.1
BuildRequires:  systemd-rpm-macros
BuildRequires:  x11-tools
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  pkgconfig(xkbcommon)
%if %{with_emoji}
Requires:       %{_name}-dict-emoji = %{version}
%endif
Requires:       dconf
Requires:       iso-codes
Requires:       libibus-1_0-5 = %{version}
Requires:       python3-dbus-python
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
# ibus-setup will require typelib(Gdk) typelib(GdkX11), typelib(Gtk)
# which are provided by two packages in openSUSE, so we limit their
# versions to 3.0 only.
Requires:       typelib-1_0-Gtk-3_0
Provides:       locale(ja;ko;zh)
%if %{with_wayland}
BuildRequires:  pkgconfig(wayland-client) >= 1.2.0
%endif
%if %{with_emoji}
BuildRequires:  unicode-emoji
BuildRequires:  pkgconfig(cldr-emoji-annotation)
%endif
%endif

%description
IBus, short for Intelligent Input Bus, is an input framework. IBus
plugins then provide the particular logic how to translate keypresses
to input characters and possibly show disambiguation windows around
the text cursor.

%if ! 0%{?with_gtk4}
%package -n libibus-1_0-5
Summary:        IBus libraries
Group:          System/Libraries

%description -n libibus-1_0-5
This package contains the libraries for IBus

%package -n typelib-1_0-IBus-1_0
Summary:        Introspection bindings for IBus
Group:          System/Libraries

%description -n typelib-1_0-IBus-1_0
This package contains the introspection bindings for the IBus library.

%if %{with_emoji}
%package dict-emoji
Summary:        Emoji dictionary for IBus
Group:          System/I18n/Chinese
BuildArch:      noarch
# make sure old ibus package containing emoji dict files is updated
Conflicts:      ibus < 1.5.22

%description dict-emoji
This package contains data of emoji dictionary for IBus and other applications
%endif

%package gtk
Summary:        IBus input method support for gtk2 applications
Group:          System/I18n/Chinese
Requires:       %{_name} = %{version}
Supplements:    (ibus and gtk2)
%{gtk2_immodule_requires}

%description gtk
This package contains ibus im module for use by gtk2.

%package gtk3
Summary:        IBus input method support for gtk3 applications
Group:          System/I18n/Chinese
BuildRequires:  pkgconfig(gtk+-3.0)
Requires:       %{_name} = %{version}
Supplements:    (ibus and gtk3)
%{gtk3_immodule_requires}

%description gtk3
This package contains ibus im module for use by gtk3.

%package devel
Summary:        Development tools for ibus
Group:          Development/Libraries/Other
Requires:       dbus-1-devel
Requires:       glib2-devel
Requires:       gtk-doc
Requires:       ibus = %{version}
Requires:       libibus-1_0-5 = %{version}
Requires:       typelib-1_0-IBus-1_0 = %{version}

%description devel
The ibus-devel package contains the header files and developer
docs for ibus.

%lang_package

%else

%package -n %{_name}-gtk4
Summary:        IBus input method support for gtk4 applications
# on 15.4, both gtk4-devel and gtk4-devel-32bit provide pkgconfig(gtk4)
Group:          System/I18n/Chinese
BuildRequires:  gtk4-devel
BuildRequires:  pkgconfig(dbus-1)
Requires:       %{_name} = %{version}
Supplements:    (ibus and gtk4)
%{gtk4_immodule_requires}

%description -n %{_name}-gtk4
This package contains ibus im module for use by gtk4.
%endif

%prep
%setup -q -n %{_name}-%{version}
%patch -P 4 -p1
%patch -P 8 -p1
%if 0%{?sle_version} < 150200 && 0%{?suse_version} <=1500
%patch -P 9 -p1
%endif

cp -r %{SOURCE2} .
cp -r %{SOURCE3} .
cp -r %{SOURCE4} .
sed -i 1i"SYS_LIB=%{_lib}" xim.d-ibus-121
cp -r %{SOURCE10} .
cp -r %{SOURCE11} .

%patch -P 10 -p1
%patch -P 11 -p1
%patch -P 12 -p1
%if 0%{?suse_version} <= 1500
%patch -P 15 -p1
%endif
%patch -P 16 -p1
%patch -P 17 -p1
%patch -P 18 -p1

%build
%configure --disable-static \
           --libexecdir=%{_libexecdir}/ibus \
%if %{with_wayland}
           --enable-wayland \
%endif
%if %{with_emoji}
           --enable-emoji-dict \
%else
           --disable-emoji-dict \
%endif
           --disable-python2 \
%if ! 0%{?with_gtk4}
           --enable-gtk3 \
           --disable-gtk4 \
           --enable-vala \
           --enable-appindicator \
           --with-python=python3 \
           --enable-python-library \
           --enable-introspection \
           --enable-gtk-doc \
           --enable-surrounding-text \
%else
           --disable-dconf \
           --disable-emoji-dict \
           --disable-unicode-dict \
           --disable-xim \
           --disable-gtk2 \
           --disable-gtk3 \
           --enable-gtk4 \
%endif

# non-parallel to have reproducible results in spite of non-deterministic build scripts https://github.com/ibus/ibus/issues/2272
make

%install
%make_install

# Remove libtool archives
find %{buildroot} -type f -name "*.la" -delete -print

%if ! 0%{?with_gtk4}
# autostart
mkdir -p %{buildroot}%{_distconfdir}/X11/xim.d/
install -m 644 xim.d-ibus-121 %{buildroot}%{_distconfdir}/X11/xim.d/ibus
mkdir -p %{buildroot}%{_bindir}
install -c -m 0755 ibus-autostart %{buildroot}%{_bindir}/ibus-autostart
mkdir -p %{buildroot}%{_sysconfdir}/xdg/autostart
install -c -m 0644 ibus-autostart.desktop %{buildroot}%{_sysconfdir}/xdg/autostart/ibus-autostart.desktop

# systemd conf
mkdir -p %{buildroot}%{_userunitdir}/org.freedesktop.IBus.session.generic.service.d
install -c -m 0644 %{SOURCE12} %{buildroot}%{_userunitdir}/org.freedesktop.IBus.session.generic.service.d

PRIORITY=40
pushd %{buildroot}%{_distconfdir}/X11/xim.d/
    for lang in am ar as bn el fa gu he hi hr ja ka kk kn ko lo ml my \
                pa ru sk vi zh_TW zh_CN zh_HK zh_SG \
                de fr it es nl cs pl da nn nb fi en sv
    do
        mkdir $lang
        pushd $lang
            ln -s ../ibus $PRIORITY-ibus
        popd
    done
popd

mkdir -p %{buildroot}%{_datadir}/pixmaps
ln -sf %{_datadir}/icons/hicolor/48x48/apps/ibus-keyboard.png \
  %{buildroot}%{_datadir}/pixmaps/ibus-keyboard.png

# touch for %%ghost
touch %{buildroot}/%{_sysconfdir}/dconf/db/ibus

# install macros
mkdir -p %{buildroot}%{_rpmmacrodir}
install -m 644 %{SOURCE7} %{buildroot}%{_rpmmacrodir}

%suse_update_desktop_file -r org.freedesktop.IBus.Setup Settings DesktopSettings X-SuSE-Core-System

%fdupes %{buildroot}

%find_lang ibus10 %{?no_lang_C}

%pre
%systemd_user_pre org.freedesktop.IBus.session.GNOME.service org.freedesktop.IBus.session.generic.service

%post
%glib2_gsettings_schema_post
%systemd_user_post org.freedesktop.IBus.session.GNOME.service org.freedesktop.IBus.session.generic.service

%posttrans
dconf update

%preun
%systemd_user_preun org.freedesktop.IBus.session.GNOME.service org.freedesktop.IBus.session.generic.service

%postun
%glib2_gsettings_schema_postun
dconf update
%systemd_user_postun org.freedesktop.IBus.session.GNOME.service org.freedesktop.IBus.session.generic.service

%post gtk
%{gtk2_immodule_post}

%postun gtk
%{gtk2_immodule_postun}

%post -n libibus-1_0-5 -p /sbin/ldconfig
%postun -n libibus-1_0-5 -p /sbin/ldconfig

%post gtk3
%{gtk3_immodule_post}

%postun gtk3
%{gtk3_immodule_postun}

%else

# cleanup stuff that is packaged as part of the main ibus flavor
rm -rf %{buildroot}%{_datadir}
rm -rf %{buildroot}%{_includedir}
rm -rf %{buildroot}%{_bindir}
rm -rf %{buildroot}%{_libexecdir}/ibus
rm -rf %{buildroot}%{_libdir}/libibus*
rm -rf %{buildroot}%{_libdir}/pkgconfig
rm -rf %{buildroot}%{_prefix}/lib/systemd
rm -rf %{buildroot}%{_sysconfdir}/xdg

%post -n %{_name}-gtk4
%{gtk4_immodule_post}

%postun -n %{_name}-gtk4
#{gtk4_immodule_postun} there is a syntax error in the macro from gtk4-devel
if [ $1 -eq 0 ]; then
  if [[ -x %{_bindir}/gio-querymodules-64 ]]; then
    %{_bindir}/gio-querymodules-64 %{_libdir}/gtk-4.0/4.0.0/immodules
  else
    %{_bindir}/gio-querymodules %{_libdir}/gtk-4.0/4.0.0/immodules
  fi
fi
%endif

%if ! 0%{?with_gtk4}
%files
%doc AUTHORS README README.SUSE xim.ibus.suse.template
%license COPYING
%{_rpmmacrodir}/macros.ibus
%if %{defined use_usretc}
%dir %{_distconfdir}/X11
%dir %{_distconfdir}/X11/xim.d
%{_distconfdir}/X11/xim.d/*
%else
%config %{_sysconfdir}/X11/xim.d/*
%endif
%dir %{_sysconfdir}/xdg/Xwayland-session.d
%{_sysconfdir}/xdg/Xwayland-session.d/10-ibus-x11
%{_bindir}/ibus
%{_bindir}/ibus-autostart
%{_bindir}/ibus-daemon
%{_bindir}/ibus-setup
%dir %{_datadir}/ibus
%{_datadir}/ibus/component
%dir %{_datadir}/ibus/dicts
%{_datadir}/ibus/dicts/unicode-*.dict
%{_datadir}/ibus/engine
%{_datadir}/ibus/keymaps
%{_datadir}/ibus/setup
%{_datadir}/applications/org.freedesktop.IBus.Setup.desktop
%{_datadir}/applications/org.freedesktop.IBus.Panel.Wayland.Gtk3.desktop
%dir %{_datadir}/GConf
%dir %{_datadir}/GConf/gsettings
%{_datadir}/GConf/gsettings/ibus.convert
%{_datadir}/glib-2.0/schemas/org.freedesktop.ibus.gschema.xml
%{_datadir}/icons/hicolor/*/apps/ibus*.*
%{_datadir}/pixmaps/ibus-keyboard.png
%{_libexecdir}/ibus
%{_datadir}/bash-completion/completions/ibus.bash
%{_datadir}/dbus-1/services/*.service
# This file is generated by dconf update
%ghost %{_sysconfdir}/dconf/db/ibus
%dir %{_sysconfdir}/dconf/db/ibus.d
# This file is not a config file. Users may not modify it.
%config %{_sysconfdir}/dconf/db/ibus.d/00-upstream-settings
%config %{_sysconfdir}/dconf/profile/ibus
%config %{_sysconfdir}/xdg/autostart/ibus-autostart.desktop
%{_mandir}/man1/ibus.1%{ext_man}
%{_mandir}/man1/ibus-daemon.1%{ext_man}
%{_mandir}/man1/ibus-setup.1%{ext_man}
%{_mandir}/man5/00-upstream-settings.5%{ext_man}
%{_mandir}/man5/ibus.5%{ext_man}
%dir %{_userunitdir}/gnome-session.target.wants
%{_userunitdir}/gnome-session.target.wants/org.freedesktop.IBus.session.GNOME.service
%{_userunitdir}/*.service
%{_userunitdir}/org.freedesktop.IBus.session.generic.service.d

%if %{with_emoji}
%{_datadir}/applications/org.freedesktop.IBus.Panel.Emojier.desktop
%{_datadir}/applications/org.freedesktop.IBus.Panel.Extension.Gtk3.desktop
%{_mandir}/man7/ibus-emoji.7%{ext_man}
%endif
%{python3_sitearch}/gi/overrides/IBus.py
%{python3_sitearch}/gi/overrides/__pycache__/IBus.cpython-*.pyc

%files lang -f ibus10.lang

%files -n libibus-1_0-5
%{_libdir}/libibus-1.0.so.*

%if %{with_emoji}
%files dict-emoji

%dir %{_datadir}/ibus/dicts
%{_datadir}/ibus/dicts/emoji-*.dict
%endif

%files -n typelib-1_0-IBus-1_0
%{_libdir}/girepository-1.0/IBus-1.0.typelib

%files gtk
%{_libdir}/gtk-2.0/*/immodules/im-ibus.so

%files gtk3
%{_libdir}/gtk-3.0/3.0.0/immodules/im-ibus.so

%files devel
%{_libdir}/libibus-1.0.so
%{_includedir}/ibus-1.0
%{_datadir}/gtk-doc/html/ibus
%{_libdir}/pkgconfig/ibus-1.0.pc
%{_datadir}/gettext/its/ibus.*
%{_datadir}/gir-1.0/IBus-1.0.gir
%{_datadir}/vala/vapi/ibus-1.0.deps
%{_datadir}/vala/vapi/ibus-1.0.vapi

%else

%files -n %{_name}-gtk4
%dir %{_libdir}/gtk-4.0/4.0.0/immodules
%{_libdir}/gtk-4.0/4.0.0/immodules/libim-ibus.so
%endif

%changelog
* Sat Apr 12 2025 Friedrich Haubensak <hsk17@mail.de>
- Add ibus-gcc15-1.patch and ibus-gcc15-2.patch from upstream to
  fix gcc15 compile time errors
* Fri Nov  8 2024 Cliff Zhao <qzhao@suse.com>
- Upstream update to 1.5.31
  * Enhance CI for generic
  * Enhance CI for Wayland
  * Enhance compose keys
  * Update compose keys with latest Xorg and GTK
  * Use localectl to get current XKB in Wayland instead of setxkbmap
  * Update XKB engines
  * Update Unicode category
  * Change IBus unique name for security issue
  * Ignore Super modifier for compose keys for GNOME Wayland
  * Fix X11 application and game issues
  * Fix Emoji issues
  * Fix Flatpak issues
  * Fix preedit issues with m17n:sa:itrans
  * Code maintenance
* Sun Jul  7 2024 Fuminobu Takeyama <ftake@geeko.jp> - 1.5.30
- Upstream update to 1.5.30
  * Fix Super key is not handled in GTK 4 applications
  * ui/gtk3: Fix SEGV with Super-space in Wayland
  * tools: Fix ibus start/restart in Plasma Wayland 5696033
  * ui/gtk3: Fix ibus-daemon timeout in Plasma Wayland
  * ui/gtk3: Set Indicator status at launching time
  * Implement preedit color in Plasma Wayland
  * Implement ibus start/restart for Plasma Wayland
  * Show preferences menu item in activate menu
  * Fix control keys with game application
  * Fix typing freeze with barcode reader
  * Fix preedit issue with X applications
  * setup/enginedialog: Improve the search for engines
- Refresh ibus-ui-gtk3-restart-via-systemd.patch
- Drop patches merged by the upstream
  * ibus-complete-preedit-signals-for-postprocesskeyevent.patch
  * ibus-enginesimple-dont-commit-any-characters.patch
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sun Feb  4 2024 Jean Delvare <jdelvare@suse.com>
- Fix dead keys with non-English keyboard in some applications
  (MAME, Wine) (boo#1218135)
  ibus-complete-preedit-signals-for-postprocesskeyevent.patch
  ibus-enginesimple-dont-commit-any-characters.patch
* Fri Jan 19 2024 Callum Farmer <gmbr3@opensuse.org>
- Use %%_libexecdir as the basis of %%_ibus_libexecdir (bsc#1174075)
* Sat Dec  2 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.5.29
  * Add DeleteSurroundingText to PostProcessKeyEvent
  * Add preedit D-Bus signals to PostProcessKeyEvent
  * Tab should not be committed by IM
  * Translate keycodes with CapsLock
  * Update org.freedesktop.ibus.gschema.xml
  * Implement Plasma Wayland
  * Distinguish Arabic XKB and Keypad XKB options
  * Update simple.xml with xkeyboard-config 2.39
  * Fix key typing issues
  * Fix Emoji and Unicode issues
  * Fix setup dialog SEGV
  * Fix remote desktop issue
  * Enhance CI
  * Update translations
- Drop ibus-fix-key-release.patch, merged by upstream
* Wed Oct  4 2023 Marguerite Su <i@marguerite.su>
- macros.ibus:
  * set %%ibus_table_index_post() to %%nil. it'll trigger ibus-table-createdb
    to create_indexes() for the existing db. but according to upstream,
    create_indexes() is now a dummy function, and it didn't bring
    any performance improvements before. and on rpmlint side,
    it will modify the final filelist.
* Fri Mar 31 2023 Andreas Schneider <asn@cryptomilk.org>
- Fix key typing order
  * This prevents that keys get stuck in games with wine/proton (steam)
  * Added ibus-fix-key-release.patch
* Thu Mar  9 2023 Avinesh Kumar <avinesh.kumar@suse.com>
- Update version to 1.5.28
  * Implement new process_key_event for ibus-x11
  * Convert internal EN compose table to GResource
  * Enhance surrounding text
  * Enhance CI
  * Update ibusunicodegen.h with Unicode 15.0.0
  * Update simple.xml with xkeyboard-config 2.38-1
  * Fix SEGVs
* Fri Nov 18 2022 Fuminobu Takeyama <ftake@geeko.jp>
- Switch to use systemd service file to start ibus daemon
  * Fix boo#1201421
  * Add ibus-ui-gtk3-restart-via-systemd.patch
  * Enable ibus-autostart for xdg-autostart-generator
* Mon Aug 29 2022 Fuminobu Takeyama <ftake@geeko.jp>
- Do not run ibus-autostart with xdg-autostart-generator (KDE etc.)
  * A workaround for boo#1202841
  * Please use org.freedesktop.IBus.session.generic.service instead
    (See boo#1201421)
* Sat Aug 27 2022 Fuminobu Takeyama <ftake@geeko.jp> - 1.5.27
- Upstream update to 1.5.27
  * Disable XKB engines in Plasma Wayland
  * ibusimcontext keycode - 8 for gtk3 keycode generation
  * client/gtk2: Revert CCedilla change for pt-BR
  * Add IBUS_CAP_OSK to IBusCapabilite
  * Enable ibus restart in GNOME desktop
  * Add ibus im-module command
  * Implement new process_key_event for GTK4
  * src/ibusengine: Add focus_in_id()/focus_out_id() class methods
  * Delete xkb:latam:: in denylist.txt
  * Enhance Xutf8TextListToTextProperty
  * Revert Emoji shoftcut key to Super-space
  * Update simple.xml with xkeyboard-config 2.36
  * Fix refcounting issues
  * Drop ibus-fix-refcounting-issues.patch
  * Fix bashisms in org.freedesktop.IBus.session.GNOME.service
  * Update xkb-latin-layouts in gschema
  * Use our own prefix to look up systemd user services dir
  * Add functionality to change IBus panel themes with available GTK themes
  * Update translation
- Refresh im-engines-precede-xkb.patch
- Add pkgconfig(libnotify) for the GTK4 flavor
* Mon Aug 22 2022 Fuminobu Takeyama <ftake@geeko.jp>
- Fix ibus-setup to support python3 (boo#1202063)
  * Update setup-switch-im.patch
- Remove X-GNOME-* from ibus-autostart.desktop
  (boo#1201421, boo#1201728)
  * ibus-autostart still does not work with
    systemd-xdg-autostart-generator
* Tue Apr 19 2022 Yifan Jiang <yfjiang@suse.com>
- Add patch ibus-fix-refcounting-issues.patch:
  This addresses the possible GLib warnings, fixes the possible
  double unrefs happening on IBusText used in signals, and fixes
  the missing unrefs on IBusText objects created from static
  strings (gh#ibus/ibus#2387, gh#ibus/ibus#2393).
* Tue Mar 29 2022 Fuminobu Takeyama <ftake@geeko.jp>
- Add install/uninstall scripts for the user service files
- Drop ibus-missing-include.patch
  * fix build error under Leap 15.4
* Sun Mar 27 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.5.26
  * Enhance compose keys
  * Enhance Emoji features
  * Implement clear preedit for GTK4
  * Calculate keycode from keysym in GTK3 forward-key-event
  * Fix to send char position at update_preedit_text
  * Deprecate gettext.bind_textdomain_codeset() since Python 3.8
  * Fix ibus_key_event_from_string for gobject-introspection
  * Fix a key event loop with forwarding keys
  * Delete gnome-autogen dependency
  * Change XKB layout string color in panel
  * Add IBUS_INPUT_HINT_PRIVATE for browser private mode
  * mkdir socket dirs instead of socket paths
  * Add org.freedesktop.IBus.session.generic.service
  * Check XDG_SESSION_DESKTOP for Plasma desktop
  * Update simple.xml with xkeyboard-config 2.35.1
  * Update ibusunicodegen.h with unicode-ucd 14.0.0
  * Enhance CI
  * Fix typos
  * Fix wrong cursor location in gtk3 apps
  * Update URLS
  * invalidate cache based on symlink mtime too
  * Fix unref problems with floating references
  * Update man page for Emoji shortcut key
  * Add systemd unit file
  * Fix forward key keycode for GTK4
- Drop ibus-fix-wrong-cursor-location.patch, merged by upstream
* Wed Jan  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not introduce ibus-gtk4-32bit unless there will be demand for
  it: drop its definition from baselibs.conf.
* Tue Dec 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Fix name of gtk4 flavor generated packages (was ibus-gtk4-gtk4).
* Thu Dec 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Split build of gtk4 module into an own flavor, allowing us to
  break a build cycle.
* Sun Oct  3 2021 Fuminobu Takeyama <ftake@geeko.jp>
- Enable GTK 4 IM Module for Leap 15.4 and Tumbleweed
- Remove ibus-python-install-dir.patch
  * Not used for build anymore
* Wed Sep  8 2021 Predrag Ivanović <predivan@mts.rs>
- Refresh ibus-socket-name-compatibility.patch
- Add ibus-missing-include.patch to fix build on Leap
- Add ibus-fix-wrong-cursor-location.patch
  (based on https://github.com/ibus/ibus/commit/936a0e76df79d92a8bdc03e9205330fb84a2083e.patch)
  (gh#ibus/ibus#2337)
- Drop ibus-python-install-dir.patch
  Two reasons: it's for, disabled in .spec, python2, and patch forces
  the re-generation of configure, which requires aclocal-1.16,
  unavailable on Leap-15.3, and that breaks the build.
* Mon Sep  6 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.5.25
  * src/tests: Run gnome-session with no-overview mode
  * client/gtk2: Implement ibus_im_context_set_surrounding_with_selection
  * src/ibuscomposetable: Do not include the same compose file
  * src/ibusenginesimple: Multi_key to 0xB7
  * src/ibusenginesimple: Make Compose preedit less intrusive
  * Change default Emoji shortcut key
  * setup: Enhance engine search function
  * client/gtk2/ibusimcontext: Enable sync process in GTK4
  * engine: Update simple.xml with xkeyboard-config 2.33
  * src/ibuscomposetable: Add support for the include directive (lf-)
  * src/ibuscomposetable: Fix a buffer overflow in compose handling (lf-)
  * client/x11: Add support for XFixes ClientDisconnectMode (Olivier Fourdan)
  * setup: Start ibus-daemon with the --daemonize option (Gunnar Hjalmarsson)
  * src: Fix a typo in ibusenginesimple.h (user202729)
  * Update translations
* Tue Jul 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Own /usr/share/GConf and /usr/share/GConf/gsettings: the time
  has come where the migration code is drying out and we can't
  expect the deps to just be in the buildroot (but it still works).
* Wed Jun 30 2021 Hillwood Yang <hillwood@opensuse.org>
- Rollback ibus-socket-name-compatibility.patch for Leap 15. Qt5 does
  not be updated to the new version or patch for ibus on Leap 15.
  It still needs this patch on leap 15 (boo#1187202).
* Mon Feb 22 2021 Fuminobu Takeyama <ftake@geeko.jp> - 1.5.24
- Upstream update to 1.5.24
  * Add GTK4 IM module (currently disabled for openSUSE)
  * Search engine name directly
  * Update IBusInputPurpose and IBusInputHints in ibustypes.h
  * Warn deprecated IBus XKB engines /w dialog
  - Workaround for boo#1177545
  * Update simple.xml
  * Fix arguments in GLib.DBusSignalCallback for Vala 0.50
  * Fix to build emoji-*.dict in CLDR 38
  * Fix build environments
  * Hide IBus Preferences from AppStream
- Drop vala-0.50.patch, merged by upstream
- Remove old "Obsoletes" for ibus-gnome-shell and libibus-1_0-0
* Mon Feb  8 2021 Fuminobu Takeyama <ftake@geeko.jp>
- Fix the invalid desktop file for auto start (boo#1178447)
- Fix xim.d/ibus so that a Plasma session can use XDG auto start
* Mon Feb  1 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Do not build in parallel for reproducible build results (boo#1102408)
* Mon Oct 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add vala-0.50.patch: Fix build with vala 0.50 (gh#ibus/ibus#2265)
* Wed Sep 30 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.5.23
  * Generate simple.xml with denylist 6042974 508527d 37db75b 6879879 59b902a
    568d58d 6ed34f3 5959d6f 5d67a28 394d9a8 ed7bc8d e938846 3aa670e 0d90da4
    e4dd6d1
  * Accept xdigits only for Unicode typing a440942
  * Update emoji-parser with CLDR emoji annotation release-31-0-1 9a9f828
  * Update ibusunicodegen.h with unicode-ucd 13.0.0 e10fc89
  * Delete deprecated ENABLE_APPINDICATOR_ENGINE_ICON check aa3a9f0
  * Fix SEGV 02105c4 f591381
  * Fix some errors in ibus-desktop-testing-runner 7b0d091 8da0167
  * Refactor source files 0b9d936 0ad5e9a
  * Fix string formats in translatable strings 7caead1 f8c468a ce865f6
  * Use WAYLAND_DISPLAY on Wayland sessions to make up IBus socket name (Carlos
    Garnacho) 8ce2520
  * Skip parsing of compose sequence with invalid keysyms (Neil Shepperd)
    0da3cec
  * Tell Pango about the engine language in the candidate panel (Aaron Muir
    Hamilton) 3f098dc 79a09f1
  * Fix for several error spotted by static analyzer (ntfs.hard) 00adea6
  * Remove glib_check_version() in gtk immodule (Changwoo Ryu) 5765bfd
  * Build the Emoji dictionaries in parallel (Changwoo Ryu) 59d0de4
  * Update translation
- Drop 0001-Replace-the-Qt-check-for-appindicator-engine-icon-wi.patch,
  ibus-use-wayland-display-for-socket-name.patch,
  ibus-socket-name-compatibility.patch. Merged by upstream
* Thu Sep 24 2020 Cliff Zhao <qzhao@suse.com>
- Update ibus.spec: Drop the is_opensuse macro to eliminate the
  difference between SLE-15 and openSUSE-Leap (jsc#SLE-11653).
* Sat Sep 19 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Move xim.d files to /usr/etc when available, which is
  currently Tumbleweed only (boo#1176431)
* Tue May 12 2020 QK ZHU <qkzhu@suse.com>
- Add ibus-socket-name-compatibility.patch: Compatibility for
  ibus-use-wayland-display-for-socket-name.patch. This fixes Qt
  clients breakage in Wayland (bsc#1171442, gh#ibus/ibus#2195).
* Mon May 11 2020 QK ZHU <qkzhu@suse.com>
- Add ibus-use-wayland-display-for-socket-name.patch:
  Use WAYLAND_DISPLAY on Wayland sessions to make up IBus socket name
  (bsc#1171442, gh#ibus/ibus#2195).
* Wed Apr 15 2020 Cliff Zhao <qzhao@suse.com>
- Update ibus.spec: Drop the is_opensuse macro to eliminate the
  difference between SLE-15 and openSUSE-Leap (jsc#SLE-11652).
* Wed Mar 11 2020 Antonio Larrosa <alarrosa@suse.com>
- Enable wayland and emoji features in SLE 15 SP2 (boo#1165844,
  SLE-11652)
- Remove the with_kde option in the spec file and add a patch
  to remove an unneeded qt5 dependency
  * 0001-Replace-the-Qt-check-for-appindicator-engine-icon-wi.patch
* Mon Mar  9 2020 Andreas Schwab <schwab@suse.de>
- Enable emoji also on ppc
* Sat Feb 29 2020 Hillwood Yang <hillwood@opensuse.org>
- Enable emoji support on armv6l and riscv64, nodejs-emojione is no longer
  BuildRequires
- Remove invalid build options
- cleanup spec
* Mon Feb 24 2020 Fuminobu Takeyama <ftake@geeko.jp>
- Fix dependency between ibus and ibus-dict-emoji
  * Keep ibus and ibus-dict-emoji from the same source
  * Add Conflict to remove old ibus containing emoji dictionary
    files
* Sat Feb 22 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.5.22
  * GDBusAuthObserver security fix, drop
    ibus-CVE-2019-14822-GDBusServer-peer-authorization.patch
  * Use XDG_RUNTIME_DIR for Unix socket directory
  * Hangul button press handling
  * Fix deprecated APIs
  * Bug fixes
  * Fix boo#1149065
  * Fix restart crash with inotify read() (Robert Hoffmann)
  * Make session file header comment more clear (Jason)
  * Amend typos (Jason)
  * Add NotShowIn and Keywords keys to the desktop entry (Changwoo Ryu)
  * Handle small final sigma in ibus_keyval_convert_case (Alex Henrie)
  * Update translations.
- Add ibus-fix-Signal-does-not-exist.patch. Fix build on Leap 15.1 and below
* Wed Feb 19 2020 Fuminobu Takeyama <ftake@geeko.jp>
- Split ibus-dict-emoji so that KDE Plasma can use IBus's emoji
  dictionaries without IBus daemon (boo#1161584)
* Tue Feb  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- No longer recommend -lang: supplements are in use.
* Sat Jan 11 2020 Fuminobu Takeyama <ftake@geeko.jp>
- Drop ibus-delete-weak-pointer-for-vala-0.43.4.patch
  * which cannot be applied to 1.5.21
* Wed Dec 18 2019 Cliff Zhao <qzhao@suse.com>
- Add ibus-delete-weak-pointer-for-vala-0.43.4.patch:
  Backport this fix from upstream, To make ibus-1.5.19 can success
  build with vala-0.43.4 and later editions(bnc#1159079).
* Fri Sep 20 2019 Cliff Zhao <qzhao@suse.com>
- Update hide-setup-menu.patch: make it can be compile in SLE
  (openSUSE-Leap 15).
* Tue Sep 17 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add ibus-CVE-2019-14822-GDBusServer-peer-authorization.patch:
  bus: Implement GDBusAuthObserver callback, fix CVE-2019-14822.
* Thu Sep  5 2019 Fuminobu Takeyama <ftake@geeko.jp>
- Apply the change on Jun. 22 again, reverted by the previous
  change
- Stop exporting OOO_FORCE_DESKTOP (boo#1042136)
  * KDE4 LibreOffice VCL plugin was removed from upstream
  * New KDE5/Qt5 VCL plugin supporting Qt IM Module will be
    available
  * Note only LibreOffice KDE5/Qt5 >= 6.3 supports Qt IM module
  - For older version, please export OOO_FORCE_DESKTOP=gnome
    in ~/.profile
* Thu Aug 29 2019 Fuminobu Takeyama <ftake@geeko.jp>
- Upstream update to 1.5.21
  * Enable to run ibus-setup with a different python
  * Update ibusunicodegen.h for Unicode UCD 12.0
  * Add ibus.its for IME's component files
  * Make ISO 639 language names with title
  * Keep preedit cursor_pos and visible in clearing preedit text
  * Support long sequences and multiple output characters for
    compose table
  - fix boo#1138123
  * Exit ibus-daemon with parent's death
  * Update Wayland input-method protocol to unstable v1
  * Indistinguishable address of ibus-daemon
  * Update LOCALES_STRING
  * Fix typos
- Drop ibus-fix-check-abs-icon-path-support.patch
  * not necessary anymore since the current Qt is enough new
* Sat Jun 22 2019 Fuminobu Takeyama <ftake@geeko.jp>
- Stop exporting OOO_FORCE_DESKTOP (boo#1042136)
  * KDE4 LibreOffice VCL plugin was removed from upstream
  * New KDE5/Qt5 VCL plugin supporting Qt IM Module will be
    available
* Wed May  8 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Move RPM macros to %%_rpmmacrodir.
* Mon Mar  4 2019 Fuminobu Takeyama <ftake@geeko.jp>
- Fix boo#1127711
  * Remove nodejs-emojione form BuildRequires
* Sat Mar  2 2019 Fuminobu Takeyama <ftake@geeko.jp>
- Upstream update to 1.5.20
  * Support Shift-Space to insert a Space on Emojier preedit
  * Do not add emojis in compose category to emoji variants
  * Implement mouse click with Hangul in ibus side
  * Delete Gconf dependencies and migrate intool to gettext
  * Do not delete IBUS_CAP_SURROUNDING_TEXT
  * Show compose preedit with custom compose file
  * Fix Atom and Slack for Flatpak
  * Delete Super-space notification
  * Use ISO 639-3 to have names for more languages
  * introspection: Tell the GI scanner to include the C headers
  * Add Uzbek layouts
  * Allow using non-abstract UNIX domain sockets
  * Fix minor build problems, bugs, and typos
* Mon Feb 25 2019 ftake@geeko.jp
- Fix boo#1126011: fix unexpected LibreOffice's dependency on IBus
  * Remove "Supplements" for libreoffice-gnome
* Tue Sep 18 2018 schwab@suse.de
- Disable emoji support on armv6l, ppc and riscv64, which have no nodejs
  support
* Tue Sep  4 2018 Fuminobu Takeyama <ftake@geeko.jp>
- Upstream update to 1.5.19
  * IBUS_DISCARD_PASSWORD variable for the workaround of the
    password popup problem in Firefox and Chrome under GNOME X11
  * Emoji feature improvements:
    Move input focus on Emojier to engines' preedit
    Show previous emojis with "history" annotation
    Add num pad Enter, Down, Up, Left, Right on Emojier
    Fix SEGV in IBusEngine if no emoji shortcut keyis
  * Compose key feature:
    Enable preedit for compose keys
  * Bug fixes and code improvements
- Drop ibus-force-python3.patch
  * merged by upstream
- Remove ibus-python3
  * Upstream will not maintain it for Python 3 anymore
  * Drop ibus-python3-migration.patch
* Fri Jul 20 2018 tchvatal@suse.com
- Do not hardcode python in 3.6 version, they change so use wildcards
* Fri Jun  1 2018 bjorn.lie@gmail.com
- Replace python3-gobject2-devel and python3-gobject2 with
  python3-gobject-devel and python3-gobject BuildRequires and
  Requires.
- Drop gconf2-devel BuildRequires: No longer needed, nor used.
* Fri May 18 2018 jengelh@inai.de
- Trim filler wording from descriptions.
- Update Summaries and RPM groups.
* Thu Apr 19 2018 hillwood@opensuse.org
- Fix filelist for SLE.
* Tue Mar  6 2018 hillwood@opensuse.org
- Update version to 1.5.18
  * tools: Do not change keymaps with 'use-system-keyboard-layout'
  * src: Fix GVariant leaks (Carlos Garnacho)
  * src: Added some error handlings from a code review
  * src: Add libgobject.so to LDADD for Debian libtool (Danny)
  * src: Reintroduce the hex mode keybind with an environment variable (Aaron Muir Hamilton)
  * ui/gtk3: Translate input method name in ibus (Peng Wu)
  * Added DBus filtering against malware
  * Implement Unicode choice on Emojier
  * Implement ibus-extension-gtk3 for the global keybinding
  * Disable panel extension for 'gdm' and 'liveuser' user
  * ui/gtk3: Set title string in gnome-shell
  * Add ISSUE_TEMPLATE
  * Updated translations
* Thu Jan 25 2018 qzhao@suse.com
- Change xim.d-ibus-121: Unset LC_CTYPE to make LANG variable
  can change system locale successful(boo#1076854).
* Mon Jan  8 2018 tchvatal@suse.com
- Do not condition sources they all need to be present in src rpm
- Add conditionals for python2 and python3
- Use full url for github downloads instead of handmade tarball
- Use make_install macro
- Apply py3 enablement patches everywhere, no effect on py2 code
- Drop python3 split spec file as it is not needed and use only
  python3
  * As there are no dependent packages on python-ibus directly
    people should repoint their scripts to the python3 variant
  * Makefiles do not allow building both at once so stick only
    with py3 as we are disabling python2 slowly anyway
- Drop 12.2 KDE icons as the codestreams are long out of support
- Drop the kde4 icons too as we are plasma5 based now and enable
  appindicator integration for plasma5 conditionaly under KDE
  condition
* Tue Dec 19 2017 ftake@geeko.jp
- Fix boo#1073524: IBus does not work on Qt5 applicatin under
  Qt5 only environment
  * do not set QT_IM_MODULE=xim for Qt5 applications
  * use QT4_IM_MODULE for Qt4 applications
* Sun Nov 19 2017 hillwood@opensuse.org
- Enable emoji support for openSUSE.
- Use %%fdupes in python3-ibus.
* Sat Nov  4 2017 hillwood@opensuse.org
- Enable python3 build
* Sat Oct 28 2017 ftake@geeko.jp
- Update to 1.5.17
  * ui/gtk3: Emojier supports Ctrl-c,v,x and Ctrl-Shift-c
  * Make all emoji dicts for fully qualified
  * ui/gtk3: Fix SEGV of Emojier on de_DE.UTF-8
  * ui/gtk3: Do not activate emoji cells on mouse until mouse moves
  * ui/gtk3: Fix SEGV of XKeysymToKeycode() on Wayland
  * client/gtk2: include the scaling factor in Wayland
  * Add IBus portal service to support Flatpack
  * ui/gtk3: Switcher should ignore mouse until it moves
  * client/gtk2: Do not send key events to GtkIMContextSimple
  * ui/gtk3: Fix PropertyPanel position in workarea
  * ui/gtk3: Fix to enable menu button on PropertyPanel
  * ui/gtk3: Increase timeout of window filter in PropertyPanel
  * ui/gtk3: Unset GDK_CORE_DEVICE_EVENTS
  * ui/gtk3: Unref Panel and Indicator when double panels run
  * engine: Add Malay and Mongolian keymaps
  * Update translations
* Tue Aug 29 2017 alarrosa@suse.com
- Don't build the branding-openSUSE-KDE package on SLE
* Sun Jul 23 2017 ftake@geeko.jp
- Fix boo#1047912: ibus-setup crashes on Tumbleweed
  * fix missing dependency on python?-gobject-Gdk
* Sat May 27 2017 qzhao@suse.com
- Update ibus.spec: copy auto-start files to SOURCE directory
  to enable modifications before compile.
- Add ibus-disable-engines-preload-in-GNOME.patch: Disable load
  preload-engines actions in SLE, which is unnecessary for mono IMF
  in SLE and may cause CJK user login failed (bsc#1036729).
* Wed May 24 2017 ftake@geeko.jp
- Update to 1.5.16
  * Implement shortcut keys on emoji dialog
  * Move language settings from IBusEmojier to ibus-setup
  * Improve `ibus emoji` command to work on Wayland
  * Emoji-related improvements
  * Add man page of `ibus emoji` command
- Update to 1.5.15
  * Fix memory leaks
  * Fix warnings during resizing panel
  * Improve emoji lookup window
  * Support scrill event in GTK3 candidate panel
  * Avoid emoji typing during Unicode typing
  * Fix potential buffer overrun in CreateNestedListi()
  * Set emoji preview text on font setting
  * Add `ibus emoji` command
- Clean up spec file
* Sun Mar 12 2017 dimstar@opensuse.org
- Drop ibus-vala-0.36.patch: No longer needed, since vala 0.36
  re-introduced the compatibility layer.
* Wed Mar  1 2017 zaitor@opensuse.org
- Drop ibus-vala-0.18.patch: No longer needed.
* Wed Mar  1 2017 dimstar@opensuse.org
- Add ibus-vala-0.36.patch: Fix build with vala 0.36, which is
  stricter in its binding usage. Patch only respective vala
  versions.
* Wed Dec 28 2016 hillwood@opensuse.org
- Disable emoji dict build.
* Thu Aug 25 2016 hillwood@opensuse.org
- Update to 1.5.14
  * Don't warn if DISPLAY is not set.
  * Install a DBus service file
  * configure: don't hardcode pkg-config
  * conf/gconf: Fix SEGV in ibus_config_gconf_get_values
  * client/gtk2: Fix SEGV with Wayland display
  * ui/gtk3: Fix panel CSS format for GTK 3.20
  * engine: Implement Emoji typing with XKB engines
  * engine: Add emoji-list.html
  * engine: Use annotations/en.xml from unocode.org but not
    emoji-list.html
  * Fix typo in configure.ac
  * tests/ibus-engine-switch: Don't try to remove non-existing GSource
  * Fix make dist
  * Fix Croatian language code in simple.xml
  * Replace deprecated GSimpleAsyncResult with GTask since GLib 2.46
* Mon Apr 18 2016 ftake@geeko.jp
- Upstream update to 1.5.13
  * Add SetCursorLocationRelative D-Bus method
- Upstream update to 1.5.12
  * Fix ibus-daemon does not update user cache
  * Fix lookup window on a secondary monitor cannot get its correct
    size
  * Fix default position of property panel under multi monitor
    environments
  * Change language code from ISO 939-2 to ISO 639-1
  * Fix minor bugs
* Mon Apr 18 2016 ftake@geeko.jp
- Drop show-input-mode-icon.patch
  * this feature has been reimplemented in another approach
* Wed Apr 13 2016 hrvoje.senjan@gmail.com
- Own all oxygen icon subdirs, starting with KF 5.21.0, oxygen is
  no longer installed to the same location
* Wed Mar 23 2016 fcrozat@suse.com
- Do not apply SLE patches on openSUSE 13.2.
- Drop ibus-adapt-new-vala.patch, not needed after all with vala
  0.32.
* Sun Feb 28 2016 qzhao@suse.com
- Add ibus-adapt-new-vala.patch: Fix ibus compile error under
  new vala compiler in SLE Desktop 12 SP2.
* Sun Feb 28 2016 qzhao@suse.com
- Update ibus.spec: Add "Conflicts: fcitx" tag in SLE,
  This can help to keep old fcitx input-frame for people
  who updated from SLE-12-SP0 to SP1, means to avoid the exception
  which was brought by FATE#319095.
* Sun Feb 28 2016 sbrabec@suse.com
- Add support for translation-update-upstream (dummy bsc#933411).
* Sun Feb 28 2016 qzhao@suse.com
- Add setup-switch-im.patch: In SLE, if user launch ibus-setup
  without ibus service daemon running, it will warn the user and
  switch current input-frame to ibus by setting an environment
  variable. Note, the setting will make effect the next time this
  user login to desktop (bsc#899259).
* Sun Feb 28 2016 qzhao@suse.com
- Add hide-setup-menu.patch: Remove ibus-setup.desktop entry in
  SLE from desktop main menu, So it will only be launched from
  desktop indicator field now.
  This action is for insure ibus-setup runs with ibus-daemon in
  background everytime (bsc#899259).
* Wed Feb 24 2016 tiwai@suse.de
- Fix the invocation of ibus service for KDE, etc (boo#968486):
  for DEs known to support autostart (KDE, XFCE and LXCE), ibus is
  now started via XDG autostart for avoiding the race.  This should
  fix the missing ibus service.  For other DEs, ibus is still
  started in xim script, but with a slight (two seconds) delay for
  avoiding the race, too.
  Along with the change, INPUT_METHOD environment variable is set
  explicitly in xim script at startup; this is referred in XDG
  autostart so that it won't be executed when other IM is chosen.
  Last but not least, the explicit dbus-launch invocation is dropped,
  as it's known to conflict with DE's own startup of dbus
* Mon Aug 10 2015 ftake@geeko.jp
- Update to 1.5.11
  * Add Swedish svdvorak layout support
  * Improve UI of ibus-setup
  * Show property panel at bottom right under KDE
  * Enable absolute path to icon for appindicator
  * Support showing language icon and a property for Plasma 5
  * Use GTK 3 for xim
  * Load locale compose files dynamically
  * Enable sync mode for xim
  * Support vertical writing
- Enable appindicator status icon for SLE12 and Leap 42.1
  (boo#939506)
- Remove a bashism from /etc/xim.d/ibus (boo#941052)
- Requires newer vala compiler
  * Cannot compile with an incompatible return type error
  * 13.1 support should be dropped after the cause is confirmed
- Drop appindicator-absolute-icon-path.patch
  * Merged by upstream
- Add ibus-fix-check-abs-icon-path-support.patch
  * Allows to force absolute path regardless of Qt version
- Refresh show-input-mode-icon.patch
  * Do not scale up icon for the new appindicator status icon
* Sat Mar 28 2015 ftake@geeko.jp
- Fix boo#924696: settings of ibus engines are not saved
  * Remove inappropriate %%ghost from the dconf files
- Disable appindicator for 13.1
  * It requires Qt 5.3 to show icons specified by absolute path
* Thu Mar 12 2015 ftake@geeko.jp
- Update to 1.5.10
  * Fix losing focus in/out on Google Chrome
  * Fix SEGV of ibus-ui-gtk3 caused by inappropriate 'preload-engines'
  * ibus-setup tries C locale to support environment without
    en_US.UTF-8
  * Remove "Release" modifier key from ibus-setup
  * Show language rather than layout for xkb panel icon
  * Track window property offsets correctly
  * Add IBus panel icon for Plasma 5 desktop
  * Minor bug fixes
- Update show-input-mode-icon.patch
  * Support the new panel icon
- Add appindicator-absolute-icon-path.patch
  * Show icons installed out of theme directories
* Sat Jan 24 2015 antoine.belvire@laposte.net
- modify xim.d-ibus-121: remove obsolete 'PATH=$OLD_PATH' which
  causes loss of the PATH variable when sourced
* Sat Nov 22 2014 coolo@suse.com
- disable parallel build for install - not much gain and makes it
  less reliable
* Tue Oct 14 2014 hillwood@linuxfans.org
- Update to 1.5.9
  * Enable preedit color on external preedit window with x11 applications.
  * Do not fail ibus-setup when en_US.UTF-8 is not installed.
  * Fix compose keys in French layout bepo variant.
* Mon Oct 13 2014 gber@opensuse.org
- use desktop file categories Settings;DesktopSettings instead of
  System
* Wed Oct  8 2014 ftake@geeko.jp
- Add im-engines-precede-xkb.patch
  * allow users to use an IM engine without any operation
- Update the launch script
  * remove the obsolete part for SKIM (bnc#860486)
  * do not set OOO_FORCE_DESKTOP=gnome
    if libreoffice-gnome is not installed (bnc#899045)
* Mon Sep  8 2014 fcrozat@suse.com
- Do not suggest to install ibus when installing
  libreoffice/libreoffice-gnome on SLE12.
* Fri Sep  5 2014 i@marguerite.su
- properly disable python3 builds:
  * ibus itself isn't python3 ready, its python module is totally
    not usable under python3.
- move some Obsoletes to the correct sub-package.
* Sun Aug 31 2014 hillwood@linuxfans.org
- Fix bnc#893271. Keep python-ibus.
* Sat Aug 30 2014 i@marguerite.su
- Add patch: ibus-python3-migration.patch
  * I didn't do the hard "port", just simple 2to3 tasks.
  * it'll remove "blockage" or python3-ibus is totally unusable.
* Tue Aug 26 2014 fcrozat@suse.com
- Do not only requires typelib-1_0-Gtk-3_0 when building with
  python3.
* Fri Aug 22 2014 fcrozat@suse.com
- Update ibus xim script to properly detect GNOME 3.12+ and to use
  ibus default configuration on first startup of GNOME (bnc#862589
  internal), with help from Takashi Iwai.
* Mon Aug 11 2014 fcrozat@suse.com
- Fix default category for ibus-setup.desktop.
* Tue Aug  5 2014 fcrozat@suse.com
- Do not build with python3 or wayland on SLE12.
- Fix file list when building with python2.
* Thu Jul 31 2014 ftake@geeko.jp
- remove patches merged by upstream
  * add-libgnomekbd-and-load-preload-engines.patch
  * reload-preload-engines-until-users-customize-the-list.patch
- obsoletes python-ibus when packaged for Python 3
* Sun Jul 27 2014 i@marguerite.su
- fix hillwood's timestamp in changelog
- add two more macros to macros.ibus
* Sat Jul 26 2014 i@marguerite.su
- update version 1.5.8
  * Set max-width-chars property in ibus-setup wrapped GtkLabel
  * Add German (nodeadkeys) keymap in simple.xml
  * Delete Korean keymap
  * Let ibus-ui-gtk3 not to show zero-lenght preedit text
  * Fix many memory leaks provided by Christophe Fergeau
  * Add Polish (qwertz) keymap in simple.xml
  * Fix escape key with Ctrl+Shift+U ISO
  * Update ibuscomposetable.h for pt-br
  * Set up ibus engines when users log into the session for the first time
  * Do not sort ibus engines when they are saved by ibus-setup
  * Update IBusKeymap jp
  * Run xmodmap after run setxkbmap -l layout
  * Add ibus reset-config and read-config sub-commands
  * Fix ibus-setup SEGV in enginetreeview.py
  * Fix deprecated warnings with python3-gobject 3.13.3
  * Export the 'IBUS_SETUP_XID' environment variable for each engine setup
  * Fix deprecated gtk3 GtkMisc, GtkAlignment and vala Gdk.X11Display
  * Enhance UI to add engines on ibus-setup
- mask add-libgnomekbd-and-load-preload-engines.patch and
  reload-preload-engines-until-users-customize-the-list.patch
  * upstream may have fixed these issues as these patches are issued
    on May 7th.
- use python3 to build ibus, as hillwood switched ibus-table to python3
  * add ibus-force-python3.patch, because ibus will use python3 to build
    ibus-setup and bindings only when PYTHON2 variable is empty. And fix
    'print sysconfig.PREFIX' syntax errors in python-config.py.
- add ibus-vala-0.18.patch to fix build for openSUSE 12.3
* Sat Jul 26 2014 i@marguerite.su
- clean specfile with service and spec-cleaner
  * don't use vague wildcards aggresively in %%%%files section
- add macros.ibus to ease packaging
* Sat Jul 26 2014 hillwood@linuxfans.org
- Enable wayland support
* Thu Jun  5 2014 ftake@geeko.jp
- Update to 1.5.7
  * Add Czech (qwerty) keymap
  * Enables to get current input context from panels
  * Fix leakage in ibus_get_local_machine_id()
  * Do not show Property Panel by default
  * Focus-in events do not move Property Panel
    if the panel is configured to be always shown
* Tue May 20 2014 tiwai@suse.de
- Fix the lost XIM input after GNOME screen lock (bnc#874969):
  ibus-xim-fix-re-focus-after-lock.patch
* Wed May 14 2014 cxiong@suse.com
- Let GNOME 3 handles ibus startup&setup. (bnc#873016)
  * Changed xim.d-ibus-121.
  * Reformatting the latter part of the xim.d-ibus-121.
* Mon Mar 17 2014 ftake@geeko.jp
- Update to 1.5.6
  * Support python3 (not enabled for this package)
  * Fix Property Panel is sometimes not shown when the focus is changed
  * Let Property Panel not to follow cursor if it is always shown
  * Fix a build error of Gdk.EventKey with vala 0.23.2
  * Use XKB layout strings instead of the ibus-keyboard icon on the panel
- Update reload-preload-engines-until-users-customize-the-list.patch
- Update ibus-python-install-dir.patch
  * modify Python 2 path in configure.ac instead of Makefile.am
- Refresh add-libgnomekbd-and-load-preload-engines.patch
* Mon Mar 17 2014 fcrozat@suse.com
- Clean-up dependencies: add librsvg2 (needed by ibus), dropped
  notification-daemon, python-gtk, python-notify (not needed with
  switch to pygobject), typelib-1_0-Gtk-2_0, typelib-1_0-Gtk-3_0
  (no need to hardcode, bnc#868657)
* Fri Feb 14 2014 tiwai@suse.de
- Fix *-32bit post and postun calls for gtk-query-immodules-2 on
  openSUSE 13.1 and later (bnc#845860)
* Mon Feb 10 2014 fcrozat@suse.com
- Do not requires gobject-introspection, it is not needed to run
  ibus, python-gobject is enough.
* Mon Jan 27 2014 ftake@geeko.jp
- Update to 1.5.5
  * Add Property Panel showing IME properties
  * Add French layout variant “oss” and the Slovak qwerty layout
  * Support customizing the look-up-table orientation of ibus-ui-gtk3.
  * Update en-us compose table and add locale tables for xkb engines
  * Delete the up/down buttons and the message about them on ibus-setup.
  * Fix candidate panel placed out of screen
  * Remove -Werror in autogen.sh
- Remove Always-save-the-content-type-cache-for-gnome-shell-p.patch
  * mergerd by upstream
- Refresh show-input-mode-icon.patch
- Update reload-preload-engines-until-users-customize-the-list.patch
  and add-libgnomekbd-and-load-preload-engines.patch
  * fix ibus-ui-gtk3 crashes if layout is en_intl (bnc#859354)
* Mon Nov 25 2013 hillwood@linuxfans.org
- Better way to fix cursor following problem (on_the_spot bug)
  under libreoffice-kde4 (bnc#851982).
* Sat Nov 16 2013 jengelh@inai.de
- Add missing python-gobject dependency (bnc#850792)
* Thu Oct 31 2013 tiwai@suse.de
- Always-save-the-content-type-cache-for-gnome-shell-p.patch:
  This is an additional fix patch for ibus to avoid the wrong
  IBus.InputPurpose.PASSWORD advertisement, which leads to the
  password text appearance on GNOME3 (bnc#847718)
* Thu Oct 17 2013 i@marguerite.su
- add a branding-openSUSE-KDE subpackage.
  * provides kde monochrome icons for 13.1 default KDE theme.
- port fix for bnc#820218 here
  * ibus qt tray icon is not in keeping with KDE monochrome icon look.
* Mon Oct 14 2013 hillwood@linuxfans.org
- Obsoletes libibus-1_0-0
* Thu Oct 10 2013 ftake@geeko.jp
- Update show-input-mode-icon.patch
  * fix ibus-ui-gtk3 hangs up
  * fix icons are cropped on KDE
* Sun Oct  6 2013 ftake@geeko.jp
- Update to 1.5.4
  * Add "address" command to command line interface
  * Support content-type of input context
  * Replace ibus-config with gsettings
  * Support using a different IM engine state for each window
  * Support show-icon-on-systray in ibus-ui-gtk3
  * Fix no output when ibus-daemon is runnin on another display
  * Update translations and fix build errors
- Add show-input-mode-icon.patch
  * workaround for the current input mode is not shown on DEs
    other than GNOME
- Rename and refresh patches
  * add-libgnomekbd-and-load-preload-engines.patch
  * reload-preload-engines-until-users-customize-the-list.patch
- Fix ibus-lang is not installed
- Fix warning by "touch /etc/dconf/db/ibus" for 12.3 and later
* Fri Sep 13 2013 ftake@geeko.jp
- Fix dconf schema was not updated for automatic configuration
- Fix 00-upstream-settings was wrongly marked as %%config
- Fix /etc/dconf/db/ibus was not owned by package
- Add %%if %%endif for automatic configuration
* Thu Sep 12 2013 ftake@geeko.jp
- Add patches to configure ibus automatically according to the
  current environment at the first login
  * Add reload-preload-engines-until-users-customize-the-list-95fd937e.patch
  * Add add-libgnomekbd-and-load-preload-engines-69171c9c.patch
- Enable the surrounding text feature
* Tue Jul 30 2013 ftake@geeko.jp
- Update to 1.5.3
  * Add embed_preedit_text
  * Disable IM on lock screen
  * Change defalut triggers key to <Super>space
  * Add man files
  * Delete ibus.desktop
  * Add Norwegian keyboard
  * Update UI, improve performance, fix build problems
* Tue Jul  9 2013 hillwood@linuxfans.org
- Fix cursor following problem in KDE4 for libreoffice
* Thu Jul  4 2013 ftake@geeko.jp
- Merge branches on M17N:Devel and home:dimstar:branches:GNOME:Factory
  * Merge changelog and spec written by dimstar@opensuse.org
- Update to 1.5.2 by hillwood@linuxfans.org
  * Implement use-system-keyboard-layout
  * Fix crash of ibus-setup
- Update to 1.5.1 by hillwood@linuxfans.org
  * Add fr(bepo) XKB engine
  * Fix crash
- Update to 1.5.0 by douglarek@outlook.com
  * Renew IM-switch UI, logic, and shortcut customization
  * Integrate XKB keyboard layouts into IME. Now ibus can manage both
    IME and XKB layouts seamlessly
  * Improve ibus performance by replace some python components with
    vala implementations
  * Improve gobject-introspection support
  * Improve vala language support
  * New functions to restrict config signal: ibus_config_watch/unwatch
  * Remove gnome-icon-theme-legacy dependency.
  * Add version property in IBusEngineDesc.
  * Add IBusProperty.symbol for the short label.
  * Support dconf 0.13.4
  * Add ibus command line tool
  * Improve unit test
  * ibus-daemon now monitors .xml files by default
  * "make check" does not require "make install"
  * Support out-of-tree build
  * pygobject override is added to help migrate from the old python binding.
  * Many bug fixings.
- Switch to dconf from GConf
- Add python bindings
- Add vala bindings
- Drop obsoleted patches:
  * ibus-fix-default-preload-engines.patch
  * ibus-fix-docs-build-error.patch
  * ibus-fix-tray-icon-on-gnome-3.6.patch
  * ibus_indicator-14.patch
- Obsoletes ibus-gnome-shell
- Separate translation files into ibus-lang
- Rename libibus-1_0-0 subpackage to libibus-1_0-5, following
  upstreams soname change.
- Clean up spec file
  * remove special cases for 11.4 and 12.1
* Tue Apr  2 2013 ftake@geeko.jp
- add "Supplements" tag to ibus-gnome-shell
* Thu Mar 28 2013 i@marguerite.su
- fix a typo in Group
- fix python-bytecode-inconsistent-mtime
* Thu Mar 28 2013 jengelh@inai.de
- Put gnome-shell integration files into separate package because
  these (since openSUSE 12.3) pull in a lot of new unwanted packages
  on a GNOME-less system compared to 12.2. (bnc#812298)
- Set versions on BuildRequires according to configure.ac
- Use more robust make install call
- Remove redundant %%clean section
* Sat Feb 16 2013 ftake@geeko.jp
- better solution for bnc#802967
  * add ibus_indicator-14.patch: a shell extension for GNOME 3.6
  * update ibus-fix-tray-icon-on-gnome-3.6.patch
* Sat Feb  9 2013 hillwood@linuxfans.org
- fix bnc#802967
  * fix ibus's tray icon can't show in gnome-shell 3.6 for openSUSE 12.3,
    add ibus-fix-tray-icon-on-gnome-3.6.patch
* Thu Jan 10 2013 ftake@geeko.jp
- add ibus-fix-docs-build-error.patch: to fix build error
  in Factory
* Wed Oct 17 2012 douglarek@outlook.com
-  .spec file optimization
  * remove commented patch lines
  * use `make %%{?_smp_mflags}` instead of `make %%{?jobs:-j%%jobs}`
    see: http://en.opensuse.org/openSUSE:Specfile_guidelines#Parallel_make
* Sat Aug 25 2012 hillwood@linuxfans.org
- update to 1.4.2
  Some bug fixings
* Mon Jun 18 2012 tiwai@suse.de
- Move the strict dependency on libibus-1_0-0 to ibus main package;
  otherwise user may get the inconsistent setups
* Thu May 17 2012 swyear@gmail.com
- remove soft link in RPM_BUILD_ROOT
* Thu May 17 2012 swyear@gmail.com
- mkdir target directory before link
* Thu May 17 2012 swyear@gmail.com
- fix build error in Factory: ln should be done in buildroot
* Wed Mar  7 2012 hillwood@linuxfans.org
- Fix FSF-address warnings in RPMLINT report
* Wed Mar  7 2012 hillwood@linuxfans.org
- Update to 1.4.1
  * Many bug fixings
- Fix several RPMLINT report warnings
* Sun Feb 12 2012 ftake@geeko.jp
- Fix problem default preload engines do not work (bnc#746612)
- Fix slow down issue after "source xim.d/ibus" in a SSH session
* Tue Jan 24 2012 vuntz@opensuse.org
- Split typelib file into typelib-1_0-IBus-1_0 subpackage.
- Add typelib-1_0-IBus-1_0 Requires to devel subpackage.
* Thu Oct 13 2011 tiwai@suse.de
- Add obsoletes for libibus2-32bit in baselibs.conf
* Wed Oct 12 2011 ftake@geeko.jp
- update to 1.4.0
  * Status icon for GNOME 3 (bug#723591)
* Tue Sep  6 2011 ftake@geeko.jp
- Fix xim.d/ibus to launch D-Bus daemon (only for newer D-Bus)
* Mon Aug  8 2011 tiwai@suse.de
- Fix baselibs.conf to update GTK immodule cache properly for
  ibus-gtk-32bit and ibus-gtk3-32bit packages, too
- Clean up spec file
* Mon Jun 27 2011 tiwai@suse.de
- dropped the dependencies with release number
- simplify for passing gtk3 configure option
* Sun Jun 19 2011 swyear@gmail.com
- Change files in package, some should move to devel subpackage and libibus package
* Thu Jun 16 2011 tiwai@suse.de
- Fix xim.d locale directories of ja and ko
- Add xim.d selections for more locales to replace with SCIM
* Wed Jun 15 2011 tiwai@suse.de
- Add provides tag for supported locales (ja, ko, zh)
- Add proper supplements tags to gtk immodule packages
* Mon Jun 13 2011 swyear@gmail.com
- Update to ibus 1.3.9
- Set priority to 40, if we want to use ibus as default input method,
  better use a lower priority, so if any other input method framework
  installed, system can use other input method instead.
- Update README
- Remove kimpanel script from start up script
- Add gtk3 immodule
* Wed Mar  9 2011 tiwai@suse.de
- Fix post scripts to use new gtk2_immodule_* macros (bnc#678080)
* Wed Nov 17 2010 mxwu@novell.com
- Upgrade to ibus 1.3.8:
  * Fix CPU 100%% usage with signal.SIGCHLD
  * Destroy existing connection before creating a new
    connection, and only create the fake context once.
  * Move the candidate window just above the cursor
    when the window and a preedit string overlap.
  * Enable key snooper by default again
  * Always consume the hotkey, even if the hotkey
    associated engine already activated.
  * Fix race condition in bus_ibus_impl_create_engine()
  * Fix a build error of IBus-1.0.gir with gobject-introspection 0.9.6
  * Implement stress tool for ibus.
  * Fix a build error with GTK3 gdkkeysyms.h
  * Add time info in log message from satorux@chromium.org
  * Fix memory leak in ibus_input_context_process_key_event by Fujiwarat
  * Fix segv in bus_engine_proxy_process_key_event_reply_cb
  * Fix property issue.
  * Updated many translations.
* Tue Jul 13 2010 mxwu@novell.com
- Add ibus-disable-portability-check.patch
  * Disable automake's portability check, make OBS happy.
* Mon Jul 12 2010 mxwu@novell.com
- Upgrade to 1.3.6:
  * Support gtk3
  * Support gobject-introspection
  * Support vala language
  * Fix some bugs
* Tue May 11 2010 mxwu@novell.com
- Upgrade to 1.3.3:
  * Add configure option to disable key snooper in gtk im context
  * Fix a crash in ibus-x11
  * Fix a crash in ibus-daemon
  * For show language bar option, use {Embedded in menu} to replace {Never}.
  * Update some translation files
  * Fix crash if ibus loads engine.xml failed
  * Fix focus problems
  * Does not hard code iso-codes location
  * Fix link problem with binutils-gold
  * Updated translations
  * Optimize database query method for better performance
  * Many bug fixing
  * use floating IBusObject
  * support share one global engine in all applications
  * some ui improvements
  * many bug fixing
* Fri Mar 26 2010 tiwai@suse.de
- move post scriptlets to install
* Wed Mar 24 2010 tiwai@suse.de
- Split libibus1 subpackage
- Misc clean-ups in spec file, avoid unnecessary workarounds
* Thu Jan 28 2010 mxwu@novell.com
- Add ibus-python-install-dir.patch
  - Fix the installing path on X86_64
* Thu Jan 28 2010 mxwu@novell.com
- Initial import
